<?php

/**
 * Slash Admin Options page
 * 
 * @package Slash Admin
 * @since 1.0
 */
class Slash_Admin_Options {
	
	private $sections;
	private $checkboxes;
	private $settings;
	
	/**
	 * Construct
	 *
	 * @since 1.0
	 */
	public function __construct() {
		
		// This will keep track of the checkbox options for the validate_settings function.
		$this->checkboxes = array();
		$this->settings = array();
		$this->get_settings();
		
		$this->sections['appearance']   = __( 'Appearance' , 'slashadmin' );
		$this->sections['administration']   = __( 'Administration' , 'slashadmin' );
		$this->sections['frontend_usability']   = __( 'Frontend usability' , 'slashadmin' );
		$this->sections['backend_usability']   = __( 'Backend usability' , 'slashadmin' );
		$this->sections['shortcodes']   = __( 'Shortcodes' , 'slashadmin' );
		$this->sections['compatibility']   = __( 'Compatibility' , 'slashadmin' );
		$this->sections['about']     = __( 'Documentation' , 'slashadmin' );
		
		add_action( 'admin_menu', array( &$this, 'add_pages' ) );
		add_action( 'admin_init', array( &$this, 'register_settings' ) );
		
		if ( ! get_option( 'slashadmin_options' ) )
			$this->initialize_settings();
		
	}
	
	/**
	 * Add options page
	 *
	 * @since 1.0
	 */
	public function add_pages() {
		
		$admin_page = add_management_page( __( 'Slash Admin Options' , 'slashadmin' ), __( 'Slash Admin' , 'slashadmin' ), 'manage_options', 'slashadmin-options', array( &$this, 'display_page' ) );
		
		add_action( 'admin_print_scripts-' . $admin_page, array( &$this, 'slashadmin_scripts' ) );
		add_action( 'admin_print_styles-' . $admin_page, array( &$this, 'styles' ) );
		
	}
	
	/**
	 * Create settings field
	 *
	 * @since 1.0
	 */
	public function create_setting( $args = array() ) {
		
		$defaults = array(
			'id'      => 'default_field',
			'title'   => __( 'Default Field' , 'slashadmin' ),
			'desc'    => __( 'This is a default description.' , 'slashadmin' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'general',
			'choices' => array(),
			'class'   => '',
			'para' => ''
		);
			
		extract( wp_parse_args( $args, $defaults ) );
		
		$field_args = array(
			'type'      => $type,
			'id'        => $id,
			'desc'      => $desc,
			'std'       => $std,
			'choices'   => $choices,
			'label_for' => $id,
			'class'     => $class,
			'paragraph' => $para
		);
		
		if ( $type == 'checkbox' )
			$this->checkboxes[] = $id;
		
		add_settings_field( $id, $title, array( $this, 'display_setting' ), 'slashadmin-options', $section, $field_args );
	}
	
	/**
	 * Display options page
	 *
	 * @since 1.0
	 */
	public function display_page() {
		
		echo '<div class="wrap">
	<div class="icon32" id="icon-options-general"></div>
	<h2>' . __( 'Slash Admin Options' , 'slashadmin' ) . '</h2>';
	
		if ( isset( $_GET['settings-updated'] ) && $_GET['settings-updated'] == true )
			echo '<div class="updated fade"><p>' . __( 'Options updated.' , 'slashadmin' ) . '</p></div>';
		
		echo '<form action="options.php" method="post">';
	
		settings_fields( 'slashadmin_options' );
		echo '<div class="ui-tabs">
			<ul class="ui-tabs-nav">';
		
		foreach ( $this->sections as $section_slug => $section )
			echo '<li><a href="#' . $section_slug . '">' . $section . '</a></li>';
		
		echo '</ul>';
		do_settings_sections( $_GET['page'] );
		
		echo '</div>
		<p class="submit"><input name="Submit" type="submit" class="button-primary" value="' . __( 'Save Changes' , 'slashadmin' ) . '" /></p>
		
	</form>';
	
	echo '<script type="text/javascript">
		jQuery(document).ready(function($) {
			var sections = [];';
			
			foreach ( $this->sections as $section_slug => $section )
				echo "sections['$section'] = '$section_slug';";
			
			echo 'var wrapped = $(".wrap h3").wrap("<div class=\"ui-tabs-panel\">");
			wrapped.each(function() {
				$(this).parent().append($(this).parent().nextUntil("div.ui-tabs-panel"));
			});
			$(".ui-tabs-panel").each(function(index) {
				$(this).attr("id", sections[$(this).children("h3").text()]);
				if (index > 0)
					$(this).addClass("ui-tabs-hide");
			});
			$(".ui-tabs").tabs({
				fx: { opacity: "toggle", duration: "fast" }
			});
			
			$("input[type=text], textarea").each(function() {
				if ($(this).val() == $(this).attr("placeholder") || $(this).val() == "")
					$(this).css("color", "#999");
			});
			
			$("input[type=text], textarea").focus(function() {
				if ($(this).val() == $(this).attr("placeholder") || $(this).val() == "") {
					$(this).val("");
					$(this).css("color", "#000");
				}
			}).blur(function() {
				if ($(this).val() == "" || $(this).val() == $(this).attr("placeholder")) {
					$(this).val($(this).attr("placeholder"));
					$(this).css("color", "#999");
				}
			});
			
			$(".wrap h3, .wrap table").show();
			
			// This will make the "warning" checkbox class really stand out when checked.
			// I use it here for the Reset checkbox.
			$(".warning").change(function() {
				if ($(this).is(":checked"))
					$(this).parent().css("background", "#c00").css("color", "#fff").css("fontWeight", "bold");
				else
					$(this).parent().css("background", "none").css("color", "inherit").css("fontWeight", "normal");
			});
			
			// Browser compatibility
			if ($.browser.mozilla) 
			         $("form").attr("autocomplete", "off");
		});
	</script>
</div>';
		
	}
	
	/**
	 * Description for section
	 *
	 * @since 1.0
	 */
	public function display_section() {
		// code
	}
	
	/**
	 * Description for About section
	 *
	 * @since 1.0
	 */
	public function display_about_section() {
		
		// This displays on the "About" tab. Echo regular HTML
		
	}
	
	/**
	 * HTML output for text field
	 *
	 * @since 1.0
	 */
	public function display_setting( $args = array() ) {
		
		extract( $args );
		
		$options = get_option( 'slashadmin_options' );
		
		if ( ! isset( $options[$id] ) && $type != 'checkbox' )
			$options[$id] = $std;
		elseif ( ! isset( $options[$id] ) )
			$options[$id] = 0;
		
		$field_class = '';
		if ( $class != '' )
			$field_class = ' ' . $class;
		
		switch ( $type ) {
			
			case 'heading':
				echo '</td></tr><tr valign="top"><td colspan="2"><h4>' . $desc . '</h4><p>' . $paragraph .'</p>';
				break;
			
			case 'checkbox':
				
				echo '<input class="checkbox' . $field_class . '" type="checkbox" id="' . $id . '" name="slashadmin_options[' . $id . ']" value="1" ' . checked( $options[$id], 1, false ) . ' /> <label for="' . $id . '">' . $desc . '</label>';
				
				break;
			
			case 'select':
				echo '<select class="select' . $field_class . '" name="slashadmin_options[' . $id . ']">';
				
				foreach ( $choices as $value => $label )
					echo '<option value="' . esc_attr( $value ) . '"' . selected( $options[$id], $value, false ) . '>' . $label . '</option>';
				
				echo '</select>';
				
				if ( $desc != '' )
					echo '<br /><span class="description">' . $desc . '</span>';
				
				break;

			case 'upload': // Media uploader (see: http://www.justinwhall.com/multiple-upload-inputs-in-a-wordpress-theme-options-page/)
				default:
					echo '<input id="' . $id . '" class="upload-url' . $field_class . '" type="text" name="slashadmin_options[' . $id . ']" value="' . esc_attr( $options[$id] ) . '" /><input id="st_upload_button" class="st_upload_button" type="button" name="upload_button" value="' . __( 'Upload', 'slashadmin' ) . '" />';
				
				if ( $desc != '' )
					echo '<span class="description">' . $desc . '</span>';
				
				break;
			
			case 'radio':
				$i = 0;
				foreach ( $choices as $value => $label ) {
					echo '<input class="radio' . $field_class . '" type="radio" name="slashadmin_options[' . $id . ']" id="' . $id . $i . '" value="' . esc_attr( $value ) . '" ' . checked( $options[$id], $value, false ) . '> <label for="' . $id . $i . '">' . $label . '</label>';
					if ( $i < count( $options ) - 1 )
						echo '<br />';
					$i++;
				}
				
				if ( $desc != '' )
					echo '<br /><span class="description">' . $desc . '</span>';
				
				break;
			
			case 'textarea':
				echo '<textarea class="' . $field_class . '" id="' . $id . '" name="slashadmin_options[' . $id . ']" placeholder="' . $std . '" rows="5" cols="30">' . wp_htmledit_pre( $options[$id] ) . '</textarea>';
				
				if ( $desc != '' )
					echo '<br /><span class="description">' . $desc . '</span>';
				
				break;
			
			case 'password':
				echo '<input class="regular-text' . $field_class . '" type="password" id="' . $id . '" name="slashadmin_options[' . $id . ']" value="' . esc_attr( $options[$id] ) . '" />';
				
				if ( $desc != '' )
					echo '<br /><span class="description">' . $desc . '</span>';
				
				break;
			
			case 'text':
			default:
		 		echo '<input class="regular-text' . $field_class . '" type="text" id="' . $id . '" name="slashadmin_options[' . $id . ']" placeholder="' . $std . '" value="' . esc_attr( $options[$id] ) . '" />';
		 		
		 		if ( $desc != '' )
		 			echo '<br /><span class="description">' . $desc . '</span>';
		 		
		 		break;
		 	
		}
		
	}
	
	/**
	 * Settings and defaults
	 * 
	 * @since 1.0
	 */
	public function get_settings() {
		
		/* Appearance
		===========================================*/
		
		$this->settings['favicon'] = array( // Favicon
			'title'   => __( 'Upload your favicon', 'slashadmin' ),
			'desc'    => __( 'For information and best practices visit <a href="http://codex.wordpress.org/Creating_a_Favicon" target="_blank">codex.wordpress.org</a>.', 'slashadmin' ),
			'std'     => '',
			'type'    => 'upload',
			'section' => 'appearance'
		);

		$this->settings['opensans_fix'] = array( // Font fixes
			'section' => 'appearance',
			'title'   => '', // Not used for headings.
			'desc'    => __( 'Font fixes' , 'slashadmin' ),
			'type'    => 'heading'
		);
			$this->settings['default_opensans_remove'] = array(
				'section' => 'appearance',
				'title'   => __( 'Default Open Sans font' , 'slashadmin' ),
				'desc'    => __( 'Select how you should deal with the default Open Sans fonts that WordPress uses. If you have issues with how the font is displayed on logged-in users (it usually happens with non-latin subsets), try to disable it and then re-enter them properly below.' , 'slashadmin' ),
				'type'    => 'select',
				'std'     => 'default',
				'choices' => array(
					'default' 			=> __( 'Keep the default Wordpress fonts (default)' , 'slashadmin' ),
					'remove_frontend' 	=> __( 'Remove default Open Sans from the Frontend' , 'slashadmin' ),
					'remove_backend' 	=> __( 'Remove default Open Sans from both Frontend and Backend' , 'slashadmin' )
				)
			);
			$this->settings['custom_fonts'] = array(
				'section' => 'appearance',
				'title'   => __( 'Insert custom fonts' , 'slashadmin' ),
				'desc'    => __( 'Insert your Google Web Fonts here. You can declare more than one fonts, styles and language subsets. Keep in mind that you must only fill in the part after the "http://fonts.googleapis.com/css?family=" like for example <code>Open+Sans:400,300&subset=latin,greek</code>. View more information about the font\'s structure, subsets and weights at the <a href="https://developers.google.com/fonts/docs/getting_started#Overview" target="_blank">Google Fonts help page</a>.' , 'slashadmin' ),
				'type'    => 'text',
				'std'     => '' 
			);

		/* Administration
		===========================================*/

		$this->settings['google_analytics'] = array(
			'section' => 'administration',
			'title'   => '', // Not used for headings.
			'desc'    => __( 'Google Analytics' , 'slashadmin' ),
			'type'    => 'heading'
		);
			$this->settings['analytics'] = array(
				'title'   => __( 'Analytics tracking code' , 'slashadmin' ),
				'desc'    => __( 'Add code for Google Analytics (it will be inserted before the <code>&lt;/head&gt;</code> tag).' , 'slashadmin' ),
				'std'     => '',
				'type'    => 'textarea',
				'section' => 'administration'
			);

		$this->settings['limit_revisions_header'] = array(
			'section' => 'administration',
			'title'   => '', // Not used for headings.
			'desc'    => __( 'Limit revisions' , 'slashadmin' ),
			'type'    => 'heading'
		);
			$this->settings['limit_revisions'] = array( // Limit Revisions
				'section' => 'administration',
				'title'   => __( 'Limit post revisions' , 'slashadmin' ),
				'desc'    => __( 'Limit the number of revisions that WordPress keeps for each post type. By default, an infinite number of revisions are stored if a post type supports revisions. Keep in mind that if you restrict this number, WordPress will purge the older revisions only after the post is updated.' , 'slashadmin' ),
				'type'    => 'select',
				'std'     => 'default',
				'choices' => array(
					'default' 	=> __( 'WordPress default (unlimited revisions)' , 'slashadmin' ),
					'one'		=> __( '1 revision (practically disables it)' , 'slashadmin' ),
					'two' 		=> __( '2 revisions' , 'slashadmin' ),
					'three'		=> __( '3 revisions' , 'slashadmin' ),
					'four'		=> __( '4 revisions' , 'slashadmin' ),
					'five'		=> __( '5 revisions' , 'slashadmin' ),
					'ten'		=> __( '10 revisions' , 'slashadmin' ),
					'twenty'	=> __( '20 revisions' , 'slashadmin' ),
					'fifty'		=> __( '50 revisions' , 'slashadmin' )
				)
			);

		$this->settings['prevent_editing'] = array( // Prevent updates on old posts
			'section' => 'administration',
			'title'   => __( 'Prevent updates on old posts' , 'slashadmin' ),
			'desc'    => __( 'Block post updates and deletion if the post is older than a specific period of time. Applies only to editors (admins can still edit the post as usual).' , 'slashadmin' ),
			'type'    => 'select',
			'std'     => 'default',
			'choices' => array(
				'default' 	=> __( 'Disabled' , 'slashadmin' ),
				'oneday' 	=> __( 'After one day' , 'slashadmin' ),
				'oneweek' 	=> __( 'After one week (7 days)' , 'slashadmin' ),
				'twoweeks'	=> __( 'After two weeks (14 days)' , 'slashadmin' ),
				'onemonth'	=> __( 'After one month (30 days)' , 'slashadmin' )
			)
		);

		/* Frontend usability
		===========================================*/

		$this->settings['login_screen'] = array(
			'section' => 'frontend_usability',
			'title'   => '', // Not used for headings.
			'desc'    => __( 'Login screen' , 'slashadmin' ),
			'type'    => 'heading'
		);

		$this->settings['logo'] = array( // Logo
			'title'   => __( 'Upload your logo', 'slashadmin' ),
			'desc'    => __( 'Upload the logo to appear at the login screen of your website. The plugin will try to automatically adjust the width/height but the suggested dimensions are <strong>320x80 pixels</strong>.', 'slashadmin' ),
			'std'     => '',
			'type'    => 'upload',
			'section' => 'frontend_usability'
		);

		$this->settings['login_links'] = array(
			'section' => 'frontend_usability',
			'title'   => __( 'Fix links at the login screen' , 'slashadmin' ),
			'desc'    => __( 'Fix the links at the wordpress login screen in order to link to your website instead of wordpress.org.' , 'slashadmin' ),
			'type'    => 'checkbox',
			'std'     => 1 // Set to 1 to be checked by default, 0 to be unchecked by default.
		);

		$this->settings['homepage_redirect'] = array( // Redirect to the homepage after login
			'section' => 'frontend_usability',
			'title'   => __( 'Go to homepage after login' , 'slashadmin' ),
			'desc'    => __( 'After log-in, redirect users to the website\'s homepage instead of their profile page.' , 'slashadmin' ),
			'type'    => 'checkbox',
			'std'     => 0 
			);

		$this->settings['disable_adminbar'] = array( // Disable Admin Bar for non Admins.
			'section' => 'frontend_usability',
			'title'   => __( 'Disable Admin Bar for non Admins' , 'slashadmin' ),
			'desc'    => __( 'Disable the Admin Bar for all users except Administrators (applies only to the front-end).' , 'slashadmin' ),
			'type'    => 'checkbox',
			'std'     => 0 
			);

		/* Backend usability
		===========================================*/

		$this->settings['restrict_access'] = array(
			'section' => 'backend_usability',
			'title'   => '', // Not used for headings.
			'desc'    => __( 'Hide options for non-admins' , 'slashadmin' ),
			'type'    => 'heading'
		);

			$this->settings['exclude_media'] = array(
				'section' => 'backend_usability',
				'title'   => __( 'Media' , 'slashadmin' ),
				'desc'    => __( 'Exclude media' , 'slashadmin' ),
				'type'    => 'checkbox',
				'std'     => 0 
			);
			$this->settings['exclude_comments'] = array(
				'section' => 'backend_usability',
				'title'   => __( 'Comments' , 'slashadmin' ),
				'desc'    => __( 'Exclude comments' , 'slashadmin' ),
				'type'    => 'checkbox',
				'std'     => 0 
			);
			$this->settings['exclude_tools'] = array(
				'section' => 'backend_usability',
				'title'   => __( 'Tools' , 'slashadmin' ),
				'desc'    => __( 'Exclude tools' , 'slashadmin' ),
				'type'    => 'checkbox',
				'std'     => 0 
			);
			$this->settings['exclude_profile'] = array(
				'section' => 'backend_usability',
				'title'   => __( 'Profile' , 'slashadmin' ),
				'desc'    => __( 'Exclude profile' , 'slashadmin' ),
				'type'    => 'checkbox',
				'std'     => 0 
			);
			$this->settings['exclude_posts'] = array(
				'section' => 'backend_usability',
				'title'   => __( 'Posts' , 'slashadmin' ),
				'desc'    => __( 'Exclude posts' , 'slashadmin' ),
				'type'    => 'checkbox',
				'std'     => 0 
			);
			$this->settings['exclude_pages'] = array(
				'section' => 'backend_usability',
				'title'   => __( 'Pages' , 'slashadmin' ),
				'desc'    => __( 'Exclude pages' , 'slashadmin' ),
				'type'    => 'checkbox',
				'std'     => 0 
			);
			$this->settings['exclude_jetpack'] = array(
				'section' => 'backend_usability',
				'title'   => __( 'Jetpack' , 'slashadmin' ),
				'desc'    => __( 'Exclude Jetpack plugin' , 'slashadmin' ),
				'type'    => 'checkbox',
				'std'     => 0 
			);
			$this->settings['exclude_custom'] = array(
				'section' => 'backend_usability',
				'title'   => __( 'Custom excludes' , 'slashadmin' ),
				'desc'    => __( 'Exclude other options such as custom post types or even the Dashboard. To do so, add the names separated with commas and no blank spaces like for example <code>Dashboard,Pages,Media,Posts</code> etc. You can exclude <strong>up to 5 additional items</strong>.' , 'slashadmin' ),
				'type'    => 'text',
				'std'     => '' 
			);

			$this->settings['hide_update_notices'] = array( // Hide update notices for all but Admins
				'section' => 'backend_usability',
				'title'   => __( 'Hide update notices to non Admins' , 'slashadmin' ),
				'desc'    => __( 'Hide the notices for updating Wordpress and other plugins for all users except from Admins' , 'slashadmin' ),
				'type'    => 'checkbox',
				'std'     => 0 
			);

		$this->settings['editors_allow_header'] = array( // Show extra options to Editors
			'section' => 'backend_usability',
			'title'   => '', // Not used for headings.
			'desc'    => __( 'Show extra options to Editors' , 'slashadmin' ),
			'type'    => 'heading'
		);
			$this->settings['editors_allow_menus'] = array(
				'section' => 'backend_usability',
				'title'   => __( 'Menus' , 'slashadmin' ),
				'desc'    => __( 'Allow Editors to manage the website\'s menus.' , 'slashadmin' ),
				'type'    => 'checkbox',
				'std'     => 0 
			);
			$this->settings['editors_allow_widgets'] = array(
				'section' => 'backend_usability',
				'title'   => __( 'Widgets' , 'slashadmin' ),
				'desc'    => __( 'Allow Editors to manage the website\'s widgets.' , 'slashadmin' ),
				'type'    => 'checkbox',
				'std'     => 0 
			);
			$this->settings['editors_allow_customizer'] = array(
				'section' => 'backend_usability',
				'title'   => __( 'Customizer' , 'slashadmin' ),
				'desc'    => __( 'Allow Editors access to the Theme Customizer.' , 'slashadmin' ),
				'type'    => 'checkbox',
				'std'     => 0 
			);
			$this->settings['editors_allow_background'] = array(
				'section' => 'backend_usability',
				'title'   => __( 'Background' , 'slashadmin' ),
				'desc'    => __( 'Allow Editors to change the website\'s background (check this only if your theme has support for WordPress\' <a href="http://codex.wordpress.org/Function_Reference/add_theme_support#Custom_Background" target="_blank">Custom Background</a> feature).' , 'slashadmin' ),
				'type'    => 'checkbox',
				'std'     => 0 
			);

		/* Shortcodes
		===========================================*/
		$this->settings['old_browsers'] = array(
			'section' => 'shortcodes',
			'title'   => '', // Not used for headings.
			'desc'    => __( 'Shortcodes' , 'slashadmin' ),
			'type'    => 'heading'
		);
			$this->settings['shortcode_mail'] = array( // Hide update notices for all but Admins
				'section' => 'shortcodes',
				'title'   => __( 'Protect mail from harvesters' , 'slashadmin' ),
				'desc'    => __( 'If you manually include email addresses in your posts, you should consider disguising them in order to "fool" e-mail harvesters. For a more in-depth explanation on why you should do it, check the <a href="http://codex.wordpress.org/Protection_From_Harvesters" target="_blank">WordPress Codex</a>.<br />To disguise an email address, use <code>[slash_mail address="yourmail@mail.com"]</code>.<br />Use <code>[slash_mailto address="yourmail@mail.com"]</code> instead if you want to automatically make it a link as well.<br />FYI, this shortcode takes advantage of the <code>&lt;?php echo antispambot(get_the_author_email()); ?&gt;</code> function.' , 'slashadmin' ),
				'type'    => 'checkbox',
				'std'     => 0 
			);

			$this->settings['shortcode_url'] = array( // Hide update notices for all but Admins
				'section' => 'shortcodes',
				'title'   => __( 'Enable relative URLs' , 'slashadmin' ),
				'desc'    => __( 'If you develop your site on localhost or on a temporary URL, you might want to avoid absolute URLs inside posts and pages. That way you don\'t need to update your links after migrating to your actual domain.  The available options are:<br />
					<code>[slash_home]</code> retrieves the <a href="http://codex.wordpress.org/Function_Reference/home_url" target="_blank">home URI</a> for the current site.<br />
					<code>[slash_theme]</code> retrieves the <a href="http://codex.wordpress.org/Function_Reference/get_template_directory_uri" target="_blank">template directory URI</a> for the current theme.<br />
					<code>[slash_child]</code> retrieves the <a href="http://codex.wordpress.org/Function_Reference/get_stylesheet_directory_uri" target="_blank">stylesheet directory URI</a> for the current theme/child theme.<br />
					Then, you can use them like so <code>&lt;img src="[slash_child]/images/image.png" /&gt;</code>, with which you would get <code>&lt;img src="http://www.yourdomain.com/wp-content/themes/childtheme/images/image.png" /&gt;</code>' , 'slashadmin' ),
				'type'    => 'checkbox',
				'std'     => 0 
			);		


		/* Compatibility
		===========================================*/

		$this->settings['old_browsers'] = array(
			'section' => 'compatibility',
			'title'   => '', // Not used for headings.
			'desc'    => __( 'Old browser warning' , 'slashadmin' ),
			'type'    => 'heading'
		);
			$this->settings['oldie_warning'] = array( // Hide update notices for all but Admins
				'section' => 'compatibility',
				'title'   => __( 'Old IE Warning' , 'slashadmin' ),
				'desc'    => __( 'If the visitor uses an old version of Internet Explorer (aka IE8 or older) display a message at the top of the page warning him that he is using an outdated browser and that he should update to a newer one.' , 'slashadmin' ),
				'type'    => 'checkbox',
				'std'     => 0 
			);

		/* FAQ
		===========================================*/
		
		$this->settings['q0_heading'] = array(
			'section' => 'about',
			'title'   => '', // Not used for headings.
			'desc'    => __( 'My theme also supports some of this plugin\'s features. Which one should I choose?' , 'slashadmin' ),
			'type'    => 'heading',
			'para'	  => __( 'It is up to you to decide whether you will use your theme\'s options or those provided by this plugin. It is recommended, though, that you keep those settings separated from your theme and the reason is simple: If at some point you decide to switch themes, those options will be lost and you have to remember to re-enter them. Keeping them in a plugin maintains the options between themes.' , 'slashadmin' )
		);

		$this->settings['q1_heading'] = array(
			'section' => 'about',
			'title'   => '', // Not used for headings.
			'desc'    => __( 'Whant\'s wrong with the default WordPress Open Sans fonts?' , 'slashadmin' ),
			'type'    => 'heading',
			'para'	  => __( 'Since version 3.8 WordPress uses Open Sans Web Font in the admin section and on all public pages when a user is logged in (for the admin bar). Some times this causes an issue when you want to use another configuration of Open Sans for your site. If you use Open Sans in your theme and you notice inconsistencies in the font\'s display between logged in and anonymous users or if you just don\'t want Open Sans for some reason (e.g. for better speed or privacy concerns), you can disable the WordPress\' default configuration. Then, you can insert your own configuration of Open Sans either via this plugin, your theme\'s options panel or manually.' , 'slashadmin' )
		);

		$this->settings['q2_heading'] = array(
			'section' => 'about',
			'title'   => '', // Not used for headings.
			'desc'    => __( 'What does hiding options for non-admins means?' , 'slashadmin' ),
			'type'    => 'heading',
			'para'	  => __( 'Sometimes you only use certain features of Wordpress. For example, your website might have comments disabled or not using a certain feature. Also, for better usability you might want to show your users only the options that concern them. Hiding those options won\'t remove them. You, as an administrator, will always see the full list of all the available options. An editor, though, won\'t see the hidden options, which helps him focus to only those that concern him.' , 'slashadmin' )
		);

		$this->settings['q3_heading'] = array(
			'section' => 'about',
			'title'   => '', // Not used for headings.
			'desc'    => __( 'Is is wise to hide update notices from my users?' , 'slashadmin' ),
			'type'    => 'heading',
			'para'	  => __( 'Generally speaking, no. Wordpress\' default behaviour is probably the best, that\'s why the specific option is disabled by default. In some cases, though, users might get confused with those notifications or think that something is wrong with the website. In cases like that, you might want to keep the update notifications visible only for those who can apply them - namely the administrators. Keep in mind that, technically, selecting this option won\'t remove the notifications for the non-admins - it will just hide them via CSS.' , 'slashadmin' )
		);

		$this->settings['q4_heading'] = array(
			'section' => 'about',
			'title'   => '', // Not used for headings.
			'desc'    => __( 'How does allowing access to appearance settings work?' , 'slashadmin' ),
			'type'    => 'heading',
			'para'	  => __( 'You can allow editors access to one or more of the following sub-sections of the "Appearance" section: <br />- Customize<br />- Widgets<br />- Menus<br />- Background<br />Technically, by selecting even one of the above options you give editors access to the Appearance section. To prevent them from accessing unwanted subsections (e.g. you want them to see the Menus but not the Widgets) the plugin hides their links via CSS/JavaScript from both the backend and the frontend. If an editor knew the link for the Widgets subsection he/she could access it. By default the plugin respects the WordPress\' default behavior, keeping those options disabled (users have no access at all to the Appearance section).'  , 'slashadmin' )
		);

		$this->settings['q5_heading'] = array(
			'section' => 'about',
			'title'   => '', // Not used for headings.
			'desc'    => __( 'Old browser warning behaves strangely with W3TC plugin' , 'slashadmin' ),
			'type'    => 'heading',
			'para'	  => __( 'This is a known issue. When Page Caching is activated in the W3 Total Cache plugin, the old browser warning becomes unpredictable and it may appear not only in Internet Explorer 8 but in newer IE versions as well as in Chrome. To deal with the problem you need to disable either the old IE warning or the W3TC Page Cache option.'  , 'slashadmin' )
		);

		$this->settings['q6_heading'] = array(
			'section' => 'about',
			'title'   => '', // Not used for headings.
			'desc'    => __( 'Which are the minimum requirements to run this plugin?' , 'slashadmin' ),
			'type'    => 'heading',
			'para'	  => __( 'This plugin has been initially tested with Wordpress 3.7 and above. It might probably work with older versions too, but you should always use the latest version of Wordpress.'  , 'slashadmin' )
		);
		$this->settings['q7_heading'] = array(
			'section' => 'about',
			'title'   => '', // Not used for headings.
			'desc'    => __( 'I found a bug / I have a suggestion or a feature request.' , 'slashadmin' ),
			'type'    => 'heading',
			'para'	  => __( 'You can post a message at the plugin\'s <a target="_blank" href="http://wordpress.org/support/plugin/slash-admin">support forum</a> and I will to my best to help you out.'  , 'slashadmin' )
		);	
	}
	
	/**
	 * Initialize settings to their default values
	 * 
	 * @since 1.0
	 */
	public function initialize_settings() {
		
		$default_settings = array();
		foreach ( $this->settings as $id => $setting ) {
			if ( $setting['type'] != 'heading' )
				$default_settings[$id] = $setting['std'];
		}
		
		update_option( 'slashadmin_options', $default_settings );
		
	}
	
	/**
	* Register settings
	*
	* @since 1.0
	*/
	public function register_settings() {
		
		register_setting( 'slashadmin_options', 'slashadmin_options', array ( &$this, 'validate_settings' ) );
		
		foreach ( $this->sections as $slug => $title ) {
			if ( $slug == 'about' )
				add_settings_section( $slug, $title, array( &$this, 'display_about_section' ), 'slashadmin-options' );
			else
				add_settings_section( $slug, $title, array( &$this, 'display_section' ), 'slashadmin-options' );
		}
		
		$this->get_settings();
		
		foreach ( $this->settings as $id => $setting ) {
			$setting['id'] = $id;
			$this->create_setting( $setting );
		}
		
	}
	
	/**
	* jQuery Tabs
	*
	* @since 1.0
	*/
	public function slashadmin_scripts() {
		
		wp_print_scripts( 'jquery-ui-tabs' );

	wp_register_script('my-upload', plugins_url( 'js/uploader.js' , __FILE__ ) , array('jquery','media-upload','thickbox'));
	wp_enqueue_script('my-upload');

	//Media Uploader Style
	wp_enqueue_style('thickbox');
		
	}
	
	/**
	* Styling for the plugin options page
	*
	* @since 1.0
	*/
	public function styles() {
		
		wp_register_style( 'slashadmin-admin', plugins_url( 'css/slashadmin-options.css' , __FILE__ ) );
		wp_enqueue_style( 'slashadmin-admin' );
		
	}
	
	/**
	* Validate settings
	*
	* @since 1.0
	*/
	public function validate_settings( $input ) {
		
		if ( ! isset( $input['reset_plugin'] ) ) {
			$options = get_option( 'slashadmin_options' );
			
			foreach ( $this->checkboxes as $id ) {
				if ( isset( $options[$id] ) && ! isset( $input[$id] ) )
					unset( $options[$id] );
			}
			
			return $input;
		}
		return false;
		
	}
	
}

$slashadmin_options = new Slash_Admin_Options();

?>